==> jc-1.4.0.tar.gz: gnu/xml/xpath/Root.h <==
// public final class gnu.xml.xpath.Root

// class file dependencies
// @dep_class d90c61647700b7f6 gnu_xml_xpath_Expr
// @dep_class 5dda8880693fb6c gnu_xml_xpath_Path
// @dep_class 4fc1b12fbb0cffd4 gnu_xml_xpath_Pattern
// @dep_class d053883545ad9f32 gnu_xml_xpath_Root
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_xpath_Path

#include "gnu/xml/xpath/Path.h"

#ifndef _JC_gnu_xml_xpath_Root_H_
#define _JC_gnu_xml_xpath_Root_H_

// Forward structure declarations
struct _jc_gnu_xml_xpath_Expr$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Collection$object;
struct _jc_org_w3c_dom_Node$object;

// Typedefs
typedef struct _jc_gnu_xml_xpath_Root$sub_refs	_jc_gnu_xml_xpath_Root$sub_refs;
typedef struct _jc_gnu_xml_xpath_Root$sub_nonrefs	_jc_gnu_xml_xpath_Root$sub_nonrefs;
typedef struct _jc_gnu_xml_xpath_Root$refs	_jc_gnu_xml_xpath_Root$refs;
typedef struct _jc_gnu_xml_xpath_Root$nonrefs	_jc_gnu_xml_xpath_Root$nonrefs;
typedef struct _jc_gnu_xml_xpath_Root$object	_jc_gnu_xml_xpath_Root$object;

typedef const struct _jc_gnu_xml_xpath_Root$vmethods	_jc_gnu_xml_xpath_Root$vmethods;
typedef const struct _jc_gnu_xml_xpath_Root$vtable	_jc_gnu_xml_xpath_Root$vtable;
typedef const struct _jc_gnu_xml_xpath_Root$vtype	_jc_gnu_xml_xpath_Root$vtype;

// Constructors
extern void _jc_gnu_xml_xpath_Root$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_xml_xpath_Root$object *);

// Virtual methods
extern struct _jc_gnu_xml_xpath_Expr$object *_jc_gnu_xml_xpath_Root$method$clone$8aac957948447f2f(_jc_env *, struct _jc_gnu_xml_xpath_Root$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_java_lang_Object$object *_jc_gnu_xml_xpath_Root$method$evaluate$8764614230b47559(_jc_env *, struct _jc_gnu_xml_xpath_Root$object *, struct _jc_object *, jint, jint);
extern struct _jc_object *_jc_gnu_xml_xpath_Root$method$evaluate$a720b7aeb2fb20be(_jc_env *, struct _jc_gnu_xml_xpath_Root$object *, struct _jc_object *, struct _jc_object *);
extern jboolean _jc_gnu_xml_xpath_Root$method$matches$bd70941b9693d4d7(_jc_env *, struct _jc_gnu_xml_xpath_Root$object *, struct _jc_object *);
extern struct _jc_java_lang_String$object *_jc_gnu_xml_xpath_Root$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_gnu_xml_xpath_Root$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_xpath_Root$method_info$clone$8aac957948447f2f;
extern _jc_method _jc_gnu_xml_xpath_Root$method_info$evaluate$8764614230b47559;
extern _jc_method _jc_gnu_xml_xpath_Root$method_info$evaluate$a720b7aeb2fb20be;
extern _jc_method _jc_gnu_xml_xpath_Root$method_info$matches$bd70941b9693d4d7;
extern _jc_method _jc_gnu_xml_xpath_Root$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_gnu_xml_xpath_Root$vmethods {
	struct _jc_gnu_xml_xpath_Expr$object	*(*clone$8aac957948447f2f)(_jc_env *, struct _jc_gnu_xml_xpath_Root$object *, struct _jc_java_lang_Object$object *);
	struct _jc_java_lang_Object$object	*(*evaluate$8764614230b47559)(_jc_env *, struct _jc_gnu_xml_xpath_Root$object *, struct _jc_object *, jint, jint);
	struct _jc_object	*(*evaluate$a720b7aeb2fb20be)(_jc_env *, struct _jc_gnu_xml_xpath_Root$object *, struct _jc_object *, struct _jc_object *);
	jboolean	(*matches$bd70941b9693d4d7)(_jc_env *, struct _jc_gnu_xml_xpath_Root$object *, struct _jc_object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_gnu_xml_xpath_Root$object *);
};

// Vtable
struct _jc_gnu_xml_xpath_Root$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_xpath_Expr$vmethods	gnu_xml_xpath_Expr;
	_jc_gnu_xml_xpath_Pattern$vmethods	gnu_xml_xpath_Pattern;
	_jc_gnu_xml_xpath_Path$vmethods	gnu_xml_xpath_Path;
	_jc_gnu_xml_xpath_Root$vmethods	gnu_xml_xpath_Root;
};

// Vtype
struct _jc_gnu_xml_xpath_Root$vtype {
	_jc_type			type;
	_jc_gnu_xml_xpath_Root$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_xpath_Root$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_xpath_Root$refs {
    _jc_gnu_xml_xpath_Root$sub_refs	gnu_xml_xpath_Root;
    _jc_gnu_xml_xpath_Path$sub_refs	gnu_xml_xpath_Path;
    _jc_gnu_xml_xpath_Pattern$sub_refs	gnu_xml_xpath_Pattern;
    _jc_gnu_xml_xpath_Expr$sub_refs	gnu_xml_xpath_Expr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_xpath_Root$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_xpath_Root$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_xpath_Expr$sub_nonrefs	gnu_xml_xpath_Expr;
    _jc_gnu_xml_xpath_Pattern$sub_nonrefs	gnu_xml_xpath_Pattern;
    _jc_gnu_xml_xpath_Path$sub_nonrefs	gnu_xml_xpath_Path;
    _jc_gnu_xml_xpath_Root$sub_nonrefs	gnu_xml_xpath_Root;
};

// Object instance structure
struct _jc_gnu_xml_xpath_Root$object {
	_jc_gnu_xml_xpath_Root$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_xpath_Root$vtype	*vtype;
	_jc_gnu_xml_xpath_Root$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_xpath_Root$vtype _jc_gnu_xml_xpath_Root$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_xpath_Root, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_xpath_Root$class_object;

#endif	/* _JC_gnu_xml_xpath_Root_H_ */

==> jc-1.4.5.tar.gz: gnu/xml/xpath/Root.h <==
// public final class gnu.xml.xpath.Root

// class file dependencies
// @dep_class d90c61647700b7f6 gnu_xml_xpath_Expr
// @dep_class 5dda8880693fb6c gnu_xml_xpath_Path
// @dep_class 4fc1b12fbb0cffd4 gnu_xml_xpath_Pattern
// @dep_class d053883545ad9f32 gnu_xml_xpath_Root
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_xpath_Path

#include "gnu/xml/xpath/Path.h"

#ifndef _JC_gnu_xml_xpath_Root_H_
#define _JC_gnu_xml_xpath_Root_H_

// Forward structure declarations
struct _jc_gnu_xml_xpath_Expr$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Collection$object;
struct _jc_org_w3c_dom_Node$object;

// Typedefs
typedef struct _jc_gnu_xml_xpath_Root$sub_refs	_jc_gnu_xml_xpath_Root$sub_refs;
typedef struct _jc_gnu_xml_xpath_Root$sub_nonrefs	_jc_gnu_xml_xpath_Root$sub_nonrefs;
typedef struct _jc_gnu_xml_xpath_Root$refs	_jc_gnu_xml_xpath_Root$refs;
typedef struct _jc_gnu_xml_xpath_Root$nonrefs	_jc_gnu_xml_xpath_Root$nonrefs;
typedef struct _jc_gnu_xml_xpath_Root$object	_jc_gnu_xml_xpath_Root$object;

typedef const struct _jc_gnu_xml_xpath_Root$vmethods	_jc_gnu_xml_xpath_Root$vmethods;
typedef const struct _jc_gnu_xml_xpath_Root$vtable	_jc_gnu_xml_xpath_Root$vtable;
typedef const struct _jc_gnu_xml_xpath_Root$vtype	_jc_gnu_xml_xpath_Root$vtype;

// Constructors
extern void _jc_gnu_xml_xpath_Root$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_xml_xpath_Root$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_gnu_xml_xpath_Expr$object *_jc_gnu_xml_xpath_Root$method$clone$8aac957948447f2f(_jc_env *, struct _jc_gnu_xml_xpath_Root$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_gnu_xml_xpath_Root$method$evaluate$8764614230b47559(_jc_env *, struct _jc_gnu_xml_xpath_Root$object *, struct _jc_object *, jint, jint) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_gnu_xml_xpath_Root$method$evaluate$a720b7aeb2fb20be(_jc_env *, struct _jc_gnu_xml_xpath_Root$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
extern jboolean _jc_gnu_xml_xpath_Root$method$matches$bd70941b9693d4d7(_jc_env *, struct _jc_gnu_xml_xpath_Root$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_xml_xpath_Root$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_gnu_xml_xpath_Root$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_xpath_Root$method_info$clone$8aac957948447f2f;
extern _jc_method _jc_gnu_xml_xpath_Root$method_info$evaluate$8764614230b47559;
extern _jc_method _jc_gnu_xml_xpath_Root$method_info$evaluate$a720b7aeb2fb20be;
extern _jc_method _jc_gnu_xml_xpath_Root$method_info$matches$bd70941b9693d4d7;
extern _jc_method _jc_gnu_xml_xpath_Root$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_gnu_xml_xpath_Root$vmethods {
	struct _jc_gnu_xml_xpath_Expr$object	*(*clone$8aac957948447f2f)(_jc_env *, struct _jc_gnu_xml_xpath_Root$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*evaluate$8764614230b47559)(_jc_env *, struct _jc_gnu_xml_xpath_Root$object *, struct _jc_object *, jint, jint) _JC_JCNI_ATTR;
	struct _jc_object	*(*evaluate$a720b7aeb2fb20be)(_jc_env *, struct _jc_gnu_xml_xpath_Root$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
	jboolean	(*matches$bd70941b9693d4d7)(_jc_env *, struct _jc_gnu_xml_xpath_Root$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_gnu_xml_xpath_Root$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_xml_xpath_Root$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_xpath_Expr$vmethods	gnu_xml_xpath_Expr;
	_jc_gnu_xml_xpath_Pattern$vmethods	gnu_xml_xpath_Pattern;
	_jc_gnu_xml_xpath_Path$vmethods	gnu_xml_xpath_Path;
	_jc_gnu_xml_xpath_Root$vmethods	gnu_xml_xpath_Root;
};

// Vtype
struct _jc_gnu_xml_xpath_Root$vtype {
	_jc_type			type;
	_jc_gnu_xml_xpath_Root$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_xpath_Root$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_xpath_Root$refs {
    _jc_gnu_xml_xpath_Root$sub_refs	gnu_xml_xpath_Root;
    _jc_gnu_xml_xpath_Path$sub_refs	gnu_xml_xpath_Path;
    _jc_gnu_xml_xpath_Pattern$sub_refs	gnu_xml_xpath_Pattern;
    _jc_gnu_xml_xpath_Expr$sub_refs	gnu_xml_xpath_Expr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_xpath_Root$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_xpath_Root$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_xpath_Expr$sub_nonrefs	gnu_xml_xpath_Expr;
    _jc_gnu_xml_xpath_Pattern$sub_nonrefs	gnu_xml_xpath_Pattern;
    _jc_gnu_xml_xpath_Path$sub_nonrefs	gnu_xml_xpath_Path;
    _jc_gnu_xml_xpath_Root$sub_nonrefs	gnu_xml_xpath_Root;
};

// Object instance structure
struct _jc_gnu_xml_xpath_Root$object {
	_jc_gnu_xml_xpath_Root$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_xpath_Root$vtype	*vtype;
	_jc_gnu_xml_xpath_Root$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_xpath_Root$vtype _jc_gnu_xml_xpath_Root$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_xpath_Root, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_xpath_Root$class_object;

#endif	/* _JC_gnu_xml_xpath_Root_H_ */
